@@ -12,4 +12,4 @@ class Log(core.models.Log):
 
     class Meta:
         #db_table = u'"log\".\"log"'
-        db_table = u'"log"'
\ No newline at end of file
+        db_table = 'log'
\ No newline at end of file
